==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AShrBinop.h <==
// public final class soot.jimple.parser.node.AShrBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a807da4df6d8445 soot_jimple_parser_node_AShrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AShrBinop_H_
#define _JC_soot_jimple_parser_node_AShrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShrBinop$sub_refs	_jc_soot_jimple_parser_node_AShrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$refs	_jc_soot_jimple_parser_node_AShrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$nonrefs	_jc_soot_jimple_parser_node_AShrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$object	_jc_soot_jimple_parser_node_AShrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vmethods	_jc_soot_jimple_parser_node_AShrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vtable	_jc_soot_jimple_parser_node_AShrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vtype	_jc_soot_jimple_parser_node_AShrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
extern void _jc_soot_jimple_parser_node_AShrBinop$method$_init$b975aa51d23fa2df(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
extern struct _jc_soot_jimple_parser_node_TShr$object *_jc_soot_jimple_parser_node_AShrBinop$method$getShr$056ff6b960747649(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
extern void _jc_soot_jimple_parser_node_AShrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShrBinop$method$setShr$26780030e7f77d59(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$getShr$056ff6b960747649;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$setShr$26780030e7f77d59;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
	struct _jc_soot_jimple_parser_node_TShr$object	*(*getShr$056ff6b960747649)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setShr$26780030e7f77d59)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AShrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AShrBinop$vmethods	soot_jimple_parser_node_AShrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TShr$object	*__5fshr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShrBinop$refs {
    _jc_soot_jimple_parser_node_AShrBinop$sub_refs	soot_jimple_parser_node_AShrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs	soot_jimple_parser_node_AShrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShrBinop$object {
	_jc_soot_jimple_parser_node_AShrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShrBinop$vtype _jc_soot_jimple_parser_node_AShrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShrBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AShrBinop.h <==
// public final class soot.jimple.parser.node.AShrBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a807da4df6d8445 soot_jimple_parser_node_AShrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AShrBinop_H_
#define _JC_soot_jimple_parser_node_AShrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShrBinop$sub_refs	_jc_soot_jimple_parser_node_AShrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$refs	_jc_soot_jimple_parser_node_AShrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$nonrefs	_jc_soot_jimple_parser_node_AShrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShrBinop$object	_jc_soot_jimple_parser_node_AShrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vmethods	_jc_soot_jimple_parser_node_AShrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vtable	_jc_soot_jimple_parser_node_AShrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShrBinop$vtype	_jc_soot_jimple_parser_node_AShrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShrBinop$method$_init$b975aa51d23fa2df(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TShr$object *_jc_soot_jimple_parser_node_AShrBinop$method$getShr$056ff6b960747649(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShrBinop$method$setShr$26780030e7f77d59(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$getShr$056ff6b960747649;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$setShr$26780030e7f77d59;
extern _jc_method _jc_soot_jimple_parser_node_AShrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TShr$object	*(*getShr$056ff6b960747649)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setShr$26780030e7f77d59)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *, struct _jc_soot_jimple_parser_node_TShr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShrBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AShrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AShrBinop$vmethods	soot_jimple_parser_node_AShrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TShr$object	*__5fshr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShrBinop$refs {
    _jc_soot_jimple_parser_node_AShrBinop$sub_refs	soot_jimple_parser_node_AShrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AShrBinop$sub_nonrefs	soot_jimple_parser_node_AShrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShrBinop$object {
	_jc_soot_jimple_parser_node_AShrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShrBinop$vtype _jc_soot_jimple_parser_node_AShrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShrBinop_H_ */
